## Typing stubs for httplib2

This is a [type stub package](https://typing.python.org/en/latest/tutorials/external_libraries.html)
for the [`httplib2`](https://github.com/httplib2/httplib2) package. It can be used by type checkers
to check code that uses `httplib2`. This version of
`types-httplib2` aims to provide accurate annotations for
`httplib2==0.31.*`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/httplib2`](https://github.com/python/typeshed/tree/main/stubs/httplib2)
directory.

This package was tested with the following type checkers:
* [mypy](https://github.com/python/mypy/) 1.17.1
* [pyright](https://github.com/microsoft/pyright) 1.1.405

It was generated from typeshed commit
[`59c36c8bf960b1b7609af5eee3b17ecde6c48864`](https://github.com/python/typeshed/commit/59c36c8bf960b1b7609af5eee3b17ecde6c48864).